==> huaweicloudsdkiam-3.0.83-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/list_groups_for_enterprise_project_res_detail.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListGroupsForEnterpriseProjectResDetail:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'create_time': 'int',
        'description': 'str',
        'domain_id': 'str',
        'id': 'str',
        'name': 'str'
    }

    attribute_map = {
        'create_time': 'createTime',
        'description': 'description',
        'domain_id': 'domainId',
        'id': 'id',
        'name': 'name'
    }

    def __init__(self, create_time=None, description=None, domain_id=None, id=None, name=None):
        """ListGroupsForEnterpriseProjectResDetail - a model defined in huaweicloud sdk"""
        
        

        self._create_time = None
        self._description = None
        self._domain_id = None
        self._id = None
        self._name = None
        self.discriminator = None

        self.create_time = create_time
        self.description = description
        self.domain_id = domain_id
        self.id = id
        self.name = name

    @property
    def create_time(self):
        """Gets the create_time of this ListGroupsForEnterpriseProjectResDetail.

        用户组创建时间。

        :return: The create_time of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: int
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ListGroupsForEnterpriseProjectResDetail.

        用户组创建时间。

        :param create_time: The create_time of this ListGroupsForEnterpriseProjectResDetail.
        :type: int
        """
        self._create_time = create_time

    @property
    def description(self):
        """Gets the description of this ListGroupsForEnterpriseProjectResDetail.

        用户组描述。

        :return: The description of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ListGroupsForEnterpriseProjectResDetail.

        用户组描述。

        :param description: The description of this ListGroupsForEnterpriseProjectResDetail.
        :type: str
        """
        self._description = description

    @property
    def domain_id(self):
        """Gets the domain_id of this ListGroupsForEnterpriseProjectResDetail.

        租户Id。

        :return: The domain_id of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this ListGroupsForEnterpriseProjectResDetail.

        租户Id。

        :param domain_id: The domain_id of this ListGroupsForEnterpriseProjectResDetail.
        :type: str
        """
        self._domain_id = domain_id

    @property
    def id(self):
        """Gets the id of this ListGroupsForEnterpriseProjectResDetail.

        用户组Id。

        :return: The id of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListGroupsForEnterpriseProjectResDetail.

        用户组Id。

        :param id: The id of this ListGroupsForEnterpriseProjectResDetail.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """Gets the name of this ListGroupsForEnterpriseProjectResDetail.

        用户组名称。

        :return: The name of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListGroupsForEnterpriseProjectResDetail.

        用户组名称。

        :param name: The name of this ListGroupsForEnterpriseProjectResDetail.
        :type: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListGroupsForEnterpriseProjectResDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.102-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/list_groups_for_enterprise_project_res_detail.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListGroupsForEnterpriseProjectResDetail:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'create_time': 'int',
        'description': 'str',
        'domain_id': 'str',
        'id': 'str',
        'name': 'str'
    }

    attribute_map = {
        'create_time': 'createTime',
        'description': 'description',
        'domain_id': 'domainId',
        'id': 'id',
        'name': 'name'
    }

    def __init__(self, create_time=None, description=None, domain_id=None, id=None, name=None):
        """ListGroupsForEnterpriseProjectResDetail

        The model defined in huaweicloud sdk

        :param create_time: 用户组创建时间。
        :type create_time: int
        :param description: 用户组描述。
        :type description: str
        :param domain_id: 租户Id。
        :type domain_id: str
        :param id: 用户组Id。
        :type id: str
        :param name: 用户组名称。
        :type name: str
        """
        
        

        self._create_time = None
        self._description = None
        self._domain_id = None
        self._id = None
        self._name = None
        self.discriminator = None

        self.create_time = create_time
        self.description = description
        self.domain_id = domain_id
        self.id = id
        self.name = name

    @property
    def create_time(self):
        """Gets the create_time of this ListGroupsForEnterpriseProjectResDetail.

        用户组创建时间。

        :return: The create_time of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: int
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ListGroupsForEnterpriseProjectResDetail.

        用户组创建时间。

        :param create_time: The create_time of this ListGroupsForEnterpriseProjectResDetail.
        :type create_time: int
        """
        self._create_time = create_time

    @property
    def description(self):
        """Gets the description of this ListGroupsForEnterpriseProjectResDetail.

        用户组描述。

        :return: The description of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ListGroupsForEnterpriseProjectResDetail.

        用户组描述。

        :param description: The description of this ListGroupsForEnterpriseProjectResDetail.
        :type description: str
        """
        self._description = description

    @property
    def domain_id(self):
        """Gets the domain_id of this ListGroupsForEnterpriseProjectResDetail.

        租户Id。

        :return: The domain_id of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this ListGroupsForEnterpriseProjectResDetail.

        租户Id。

        :param domain_id: The domain_id of this ListGroupsForEnterpriseProjectResDetail.
        :type domain_id: str
        """
        self._domain_id = domain_id

    @property
    def id(self):
        """Gets the id of this ListGroupsForEnterpriseProjectResDetail.

        用户组Id。

        :return: The id of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListGroupsForEnterpriseProjectResDetail.

        用户组Id。

        :param id: The id of this ListGroupsForEnterpriseProjectResDetail.
        :type id: str
        """
        self._id = id

    @property
    def name(self):
        """Gets the name of this ListGroupsForEnterpriseProjectResDetail.

        用户组名称。

        :return: The name of this ListGroupsForEnterpriseProjectResDetail.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListGroupsForEnterpriseProjectResDetail.

        用户组名称。

        :param name: The name of this ListGroupsForEnterpriseProjectResDetail.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListGroupsForEnterpriseProjectResDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
